@@ -28,6 +28,11 @@
 
 #include <math.h>
 
+#ifdef Q_WS_X11
+#include <X11/Xlib.h>
+#include <X11/Xatom.h>
+#endif
+
 namespace Oxygen
 {
 
@@ -35,7 +40,20 @@ namespace Oxygen
     StyleHelper::StyleHelper( const QByteArray &componentName ):
         Helper( componentName ),
         _debugArea( KDebug::registerArea( "Oxygen ( style )" ) )
-    {}
+    {
+
+        #ifdef Q_WS_X11
+        // get display
+        Display *display = QX11Info::display();
+
+        // create compositing screen
+        QByteArray buffer;
+        QTextStream( &buffer ) << "_NET_WM_CM_S" << DefaultScreen( display );
+        _compositingManagerAtom = XInternAtom( display, buffer.constData(), False);
+
+        #endif
+
+    }
 
     //______________________________________________________________________________
     void StyleHelper::invalidateCaches( void )
@@ -625,6 +643,18 @@ namespace Oxygen
         p.drawEllipse( r );
     }
 
+    //________________________________________________________________________________________________________
+    bool StyleHelper::compositingActive( void ) const
+    {
+        #ifdef Q_WS_X11
+        // direct call to X
+        return XGetSelectionOwner( QX11Info::display(), _compositingManagerAtom ) != None;
+        #else
+        // use KWindowSystem
+        return KWindowSystem::compositingActive();
+        #endif
+    }
+
     //________________________________________________________________________________________________________
     bool StyleHelper::hasDecoration( const QWidget* widget ) const
     {
